# -*- coding: utf-8 -*-

# This code is part of Qiskit.
#
# (C) Copyright IBM 2018, 2019.
#
# This code is licensed under the Apache License, Version 2.0. You may
# obtain a copy of this license in the LICENSE.txt file in the root directory
# of this source tree or at http://www.apache.org/licenses/LICENSE-2.0.
#
# Any modifications or derivative works of this code must retain this
# copyright notice, and modified files need to carry a notice indicating
# that they have been altered from the originals.

"""
This module contains the definition of data mapping function for feature map.
"""

import functools

import numpy as np


def self_product(x):
    """
    Define a function map from R^n to R.

    Args:
        x (np.ndarray): data

    Returns:
        double: the mapped value
    """
    coeff = x[0] if len(x) == 1 else \
        functools.reduce(lambda m, n: m * n, np.pi - x)
    return coeff
